==> realestate-supervise-common-1.1.0-20241231.014802-54-sources.jar: cn/gtmap/realestate/supervise/entity/BaJzqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.util.Date;

/**
 * @author <a href="mailto:huming@gtmap.cn">huming</a>
 * @version 1.0, 2024/12/26
 * @description 居住权历史表
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_jzq_ls"
)
public class BaJzqLs {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @ywh
    private String ywh;

    @ssywh
    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String jzqr;

    @XmlAttribute
    private String fwsyqr;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String bdcdjzmh;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String jztjhyq;

    @XmlAttribute
    private Date qlqssj;

    @XmlAttribute
    private Date qljssj;

    @XmlAttribute
    private String jzqqx;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    private String dbr;

    @zxjzqywh
    @XmlAttribute
    private String zxjzqywh;

    @XmlAttribute
    private String zxjzqyy;

    @XmlAttribute
    private Date zxsj;

    @XmlAttribute
    private String zxdbr;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String fj;

    @XmlAttribute
    private String qszt;

    @bwmc
    @XmlAttribute
    private String bwmc;

    @XmlAttribute
    private String zxbwmc;

    @Nullable
    private Date sjgxsj;

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public String getZxbwmc() {
        return zxbwmc;
    }

    public void setZxbwmc(String zxbwmc) {
        this.zxbwmc = zxbwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getJzqr() {
        return jzqr;
    }

    public void setJzqr(String jzqr) {
        this.jzqr = jzqr;
    }

    public String getFwsyqr() {
        return fwsyqr;
    }

    public void setFwsyqr(String fwsyqr) {
        this.fwsyqr = fwsyqr;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getJztjhyq() {
        return jztjhyq;
    }

    public void setJztjhyq(String jztjhyq) {
        this.jztjhyq = jztjhyq;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getJzqqx() {
        return jzqqx;
    }

    public void setJzqqx(String jzqqx) {
        this.jzqqx = jzqqx;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getZxjzqywh() {
        return zxjzqywh;
    }

    public void setZxjzqywh(String zxjzqywh) {
        this.zxjzqywh = zxjzqywh;
    }

    public String getZxjzqyy() {
        return zxjzqyy;
    }

    public void setZxjzqyy(String zxjzqyy) {
        this.zxjzqyy = zxjzqyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaJzqLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.util.Date;

/**
 * @author <a href="mailto:huming@gtmap.cn">huming</a>
 * @version 1.0, 2024/12/26
 * @description 居住权历史表
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_jzq_ls"
)
public class BaJzqLs {

    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @ywh
    private String ywh;

    @ssywh
    @XmlAttribute
    private String ssywh;

    @XmlAttribute
    private String jzqr;

    @XmlAttribute
    private String fwsyqr;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String bdcdjzmh;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String jztjhyq;

    @XmlAttribute
    private Date qlqssj;

    @XmlAttribute
    private Date qljssj;

    @XmlAttribute
    private String jzqqx;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    private String dbr;

    @zxjzqywh
    @XmlAttribute
    private String zxjzqywh;

    @XmlAttribute
    private String zxjzqyy;

    @XmlAttribute
    private Date zxsj;

    @XmlAttribute
    private String zxdbr;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String fj;

    @XmlAttribute
    private String qszt;

    @bwmc
    @XmlAttribute
    private String bwmc;

    @XmlAttribute
    private String zxbwmc;

    @Nullable
    private Date sjgxsj;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public String getZxbwmc() {
        return zxbwmc;
    }

    public void setZxbwmc(String zxbwmc) {
        this.zxbwmc = zxbwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getJzqr() {
        return jzqr;
    }

    public void setJzqr(String jzqr) {
        this.jzqr = jzqr;
    }

    public String getFwsyqr() {
        return fwsyqr;
    }

    public void setFwsyqr(String fwsyqr) {
        this.fwsyqr = fwsyqr;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getBdcdjzmh() {
        return bdcdjzmh;
    }

    public void setBdcdjzmh(String bdcdjzmh) {
        this.bdcdjzmh = bdcdjzmh;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getJztjhyq() {
        return jztjhyq;
    }

    public void setJztjhyq(String jztjhyq) {
        this.jztjhyq = jztjhyq;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }

    public String getJzqqx() {
        return jzqqx;
    }

    public void setJzqqx(String jzqqx) {
        this.jzqqx = jzqqx;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getZxjzqywh() {
        return zxjzqywh;
    }

    public void setZxjzqywh(String zxjzqywh) {
        this.zxjzqywh = zxjzqywh;
    }

    public String getZxjzqyy() {
        return zxjzqyy;
    }

    public void setZxjzqyy(String zxjzqyy) {
        this.zxjzqyy = zxjzqyy;
    }

    public Date getZxsj() {
        return zxsj;
    }

    public void setZxsj(Date zxsj) {
        this.zxsj = zxsj;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }
}
